@@ -112,7 +112,7 @@ static enum hyptop_win_action l_sleep(time_t time_s, long time_us)
 	struct timespec ts;
 
 	ts.tv_sec = time_s;
-	ts.tv_nsec = time_us * 1000;
+	ts.tv_nsec = util_usecs_to_nsecs(time_us);
 
 	nanosleep(&ts, NULL);
 	return WIN_KEEP;
@@ -231,6 +231,8 @@ static void l_fmt_init(void)
 		return;
 	if (g.o.format == FMT_CSV)
 		flags |= FMT_QUOTEALL;
+	if (g.o.format == FMT_CSV || g.o.format_all)
+		flags |= FMT_KEEPINVAL;
 	if (g.o.format == FMT_JSON || g.o.format == FMT_JSONSEQ)
 		flags |= FMT_HANDLEINT;
 	util_fmt_init(stdout, g.o.format, flags, 1);
