@@ -1,35 +1,38 @@
 /*
- *
- * xcec-bridge
- *
- * Copyright IBM Corp. 2003, 2006.
- *
- * Authors: Utz Bacher <utz.bacher@de.ibm.com>
- * thanks a lot to Frank Pavlic <pavlic@de.ibm.com>
+ * xcec-bridge - HiperSockets Network Concentrator
  *
  * Parameters:
  *   also_unicast     - uni-, multi-, broadcast is bridged
  *   <no parameters>  - multi-, broadcast is bridged
  *   only broadcast   - only broadcast is bridged
- * 
+ *
+ * Copyright IBM Corp. 2003, 2017
+ *
+ * s390-tools is free software; you can redistribute it and/or modify
+ * it under the terms of the MIT license. See LICENSE for details.
  */
 
+#include <dirent.h>
+#include <errno.h>
+#include <features.h>
+#include <net/ethernet.h>
+#include <net/if.h>
+#include <netinet/in.h>
+#include <netpacket/packet.h>
+#include <signal.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/ioctl.h>
+#include <sys/socket.h>
+#include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <stdio.h>
 #include <syslog.h>
-#include <errno.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <features.h>
-#include <netpacket/packet.h>
-#include <net/ethernet.h>
-#include <sys/ioctl.h>
-#include <net/if.h>
-#include <signal.h>
-#include <string.h>
+#include <unistd.h>
+
+#include "lib/util_libc.h"
+#include "lib/zt_common.h"
 
 /* a signal causes the interfaces to be re-checked */
 
@@ -38,10 +41,7 @@
 
 #define UPDATE_SIGNAL SIGUSR1
 
-#define DEV_NAME_LEN IFNAMSIZ
-
-#define PROC_QETH_FILE "/proc/qeth"
-#define PROC_QETH_FILE_WIDTH 100
+#define DEV_NAME_SIZE IFNAMSIZ
 
 #define BUFFER_LEN 65536
 
@@ -56,7 +56,7 @@ struct int_sock {
 	int features;
 	int i_fd;
 	int o_fd;
-	char dev_name[DEV_NAME_LEN];
+	char dev_name[DEV_NAME_SIZE];
 	int mtu_warning;
 
 	struct int_sock *next;
@@ -92,7 +92,7 @@ int open_incoming_socket(char *dev_name)
 		return -1;
 	}
 
-	strncpy(if_req.ifr_name,dev_name,DEV_NAME_LEN);
+	util_strlcpy(if_req.ifr_name, dev_name, DEV_NAME_SIZE);
 	retval=ioctl(fd,SIOCGIFINDEX,&if_req);
 	if (retval==-1) {
 		syslog(LOG_ERR,"can't ioctl on raw packet socket, " \
@@ -193,111 +193,123 @@ int open_outgoing_socket(char *dev_name)
 int interface_in_list(struct int_sock *item,struct int_sock *list)
 {
 	for (;list;list=list->next) {
-		if (!strncmp(item->dev_name,list->dev_name,DEV_NAME_LEN)) {
+		if (!strncmp(item->dev_name,list->dev_name,DEV_NAME_SIZE)) {
 			return 1;
 		}
 	}
 	return 0;
 }
 
+
+int read_sys(struct int_sock **nlist)
+{
+	DIR *qdir;
+	FILE *qfile;
+	struct dirent *qde;
+	char fname[256];
+	char *tmp;
+	char if_name[256];
+	char rtr[256];
+	struct int_sock *is = NULL;
+	int i;
+
+	qdir = opendir("/sys/devices/qeth");
+	if (!qdir) {
+		syslog(LOG_ERR,"failed to open directory /sys/devices/qeth");
+		return errno;
+	}
+
+	while ((qde = readdir(qdir))) {
+		if ((qde->d_type == DT_DIR) && (qde->d_name[0] != '.')) {
+			strcpy(fname, "/sys/devices/qeth/");
+			strcat(fname, qde->d_name);
+			strcat(fname, "/if_name");
+			qfile = fopen(fname, "r");
+			if (!qfile) {
+				continue;
+			}
+			tmp = if_name;
+			while ((i = fgetc(qfile)) != EOF) {
+				if ((char)i == '\n') {
+					*tmp = 0;
+					break;
+				} else {
+					*tmp = (char)i;
+				}
+				tmp++;
+			}
+			*tmp = 0;
+			fclose(qfile);
+
+			strcpy(fname, "/sys/devices/qeth/");
+			strcat(fname, qde->d_name);
+			strcat(fname, "/route4");
+			qfile = fopen(fname, "r");
+			if (!qfile) {
+				continue;
+			}
+			tmp = rtr;
+			while ((i = fgetc(qfile)) != EOF) {
+				if ((char)i == '\n') {
+					*tmp = 0;
+					break;
+				} else {
+					*tmp = (char)i;
+				}
+				tmp++;
+			}
+			*tmp = 0;
+			fclose(qfile);
+
+			if (!strstr(rtr, "multicast") &&
+			    !strstr(rtr, "connector"))
+				continue;
+
+			is = malloc(sizeof(struct int_sock));
+			if (!is) {
+				syslog(LOG_ERR,"no memory while reading from "\
+					"/sys/devices/qeth some interface"\
+					"might not be used");
+				continue;
+			}
+
+			/* as soon as we have one interface echoeing back
+			 * broadcasts to us, we don't bridge broadcast
+			 * traffic
+			 */
+			if (!(strstr(rtr, "connector+") ||
+			      strstr(rtr, "multicast router+")))
+				do_broadcast_bridging=0;
+
+			is->mtu_warning=0;
+			util_strlcpy(is->dev_name, if_name, DEV_NAME_SIZE);
+			if (!strncmp(if_name,"hsi",3)) {
+				is->features=I_S_FEATURE_PASSTHROUGH;
+			}
+
+			is->next = *nlist;
+			*nlist = is;
+		}
+	}
+
+	closedir(qdir);
+	return 0;
+}
+
 void update_interfaces()
 {
 	struct int_sock *new_list=NULL;
 	struct int_sock *i=NULL,*j,*prev;
 	struct int_sock *new_int=NULL;
 	int i_fd,o_fd;
-	FILE *fh;
-	char buf[PROC_QETH_FILE_WIDTH];
-	int retval,line_no=2;
-	char r_dev_name[PROC_QETH_FILE_WIDTH];
-	char r_rtr[PROC_QETH_FILE_WIDTH];
-	int r;
 
 	/* if all interfaces are '+'-interfaces, we bridge broadcast */
 	do_broadcast_bridging=1;
 	update_interface_trigger=0;
 	syslog(LOG_DEBUG,"rechecking interfaces");
-	fh=fopen(PROC_QETH_FILE,"r");
-	if (!fh) {
-		syslog(LOG_ERR,"can't open %s -- won't use different " \
-		       "interfaces",PROC_QETH_FILE);
+
+	if (read_sys(&new_list))
 		return;
-	}
-	/* read the two header lines */
-	if ( (!fgets(buf,PROC_QETH_FILE_WIDTH,fh)) ||
-	     (!fgets(buf,PROC_QETH_FILE_WIDTH,fh)) ) {
-		syslog(LOG_ERR,"can't read header from %s -- "
-		       "won't use different interfaces",PROC_QETH_FILE);
-		fclose(fh);
-		return;
-	}
-
-	do {
-		line_no++;
-
-		strcpy(r_dev_name,"");
-		/* format string: devnos chpid dev_name
-		 * dev_name is what we're interested in */
-		retval=fscanf(fh,"%*s %*s %s %*s %*s %*s %*s %s",
-			      r_dev_name,r_rtr);
-		if (retval==EOF) {
-			break;
-		}
-
-		/* read the rest of the line */
-		do {
-			r=fgetc(fh);
-		} while ((r!=EOF)&&(r!='\n'));
-
-		/* dull right now, but maybe useful in the future */
-		if (retval!=2) {
-			syslog(LOG_ERR,"can't interpret line %i from " \
-			       "%s -- some interface might not be used",
-			       line_no,PROC_QETH_FILE);
-			continue;
-		}
-
-		/* we only want to forward between affected interfaces:
-		 * mc, pri, sec, p.c, s.c, mix */
-		if (!(
-		      (!strcmp(r_rtr,"mc"))||
-		      (!strcmp(r_rtr,"mc+"))||
-		      (!strcmp(r_rtr,"p.c"))||
-		      (!strcmp(r_rtr,"s.c"))||
-		      (!strcmp(r_rtr,"p+c"))||
-		      (!strcmp(r_rtr,"s+c")) )) {
-			continue;
-		}
-
-		i=malloc(sizeof(struct int_sock));
-		if (!i) {
-			syslog(LOG_ERR,"no memory while reading from %s -- " \
-				       "some interface might not be used",
-				       PROC_QETH_FILE);
-			continue;
-		}
-
-		/* as soon as we have one interface echoeing back broadcasts
-		 * to us, we don't bridge broadcast traffic */
-		if (!(
-		      (!strcmp(r_rtr,"mc+"))||
-		      (!strcmp(r_rtr,"p+c"))||
-		      (!strcmp(r_rtr,"s+c"))
-		     )) {
-			do_broadcast_bridging=0;
-		}
-
-		i->mtu_warning=0;
-		strncpy(i->dev_name,r_dev_name,DEV_NAME_LEN);
-		if (!strncmp(r_dev_name,"hsi",3)) {
-			i->features=I_S_FEATURE_PASSTHROUGH;
-		}
-
-		i->next=new_list;
-		new_list=i;
-	} while (retval!=EOF);
-
-	fclose(fh);
 
 	for (i=select_set.i_s_list;i;i=i->next) {
 		if (!interface_in_list(i,new_list)) {
@@ -306,7 +318,7 @@ void update_interfaces()
 			prev=NULL;
 			while (j) {
 				if (!strncmp(j->dev_name,i->dev_name,
-					     DEV_NAME_LEN)) {
+					     DEV_NAME_SIZE)) {
 					if (!prev) {
 						select_set.i_s_list=j->next;
 					} else {
@@ -349,7 +361,7 @@ void update_interfaces()
 				continue;
 			}
 
-			strncpy(new_int->dev_name,i->dev_name,DEV_NAME_LEN);
+			util_strlcpy(new_int->dev_name, i->dev_name, DEV_NAME_SIZE);
 			new_int->i_fd=i_fd;
 			new_int->o_fd=o_fd;
 			new_int->features=i->features;
@@ -434,14 +446,15 @@ void process_packet(struct int_sock *i_s)
 		if (s_ll.sll_pkttype==PACKET_BROADCAST) {
 			s_in.sin_addr.s_addr=INADDR_BROADCAST;
 		} else {
-			memcpy(&s_in.sin_addr,&buffer[16],4);
+			memcpy(&s_in.sin_addr, &buffer[16 + ETH_HLEN], 4);
 		}
 
-		retval=sendto(i_s_item->o_fd,buffer,buffer_len,0,
-			      (struct sockaddr *)&s_in,
-			      sizeof(struct sockaddr_in));
+		retval=sendto(i_s_item->o_fd, buffer + ETH_HLEN,
+				buffer_len - ETH_HLEN, 0,
+				(struct sockaddr *)&s_in,
+				sizeof(struct sockaddr_in));
 		if (retval==-1) {
-			if ( (errno=EMSGSIZE) && (!i_s_item->mtu_warning) ) {
+			if ( (errno==EMSGSIZE) && (!i_s_item->mtu_warning) ) {
 				syslog(LOG_WARNING,"MTU of %s too small " \
 				       "to forward packet with size of %i" \
 				       " -- won't show warning again.",
@@ -452,16 +465,15 @@ void process_packet(struct int_sock *i_s)
 				       "%s\n",i_s_item->dev_name,
 				       strerror(errno));
 			}
-		} else if (retval!=buffer_len) {
+		} else if (retval != (buffer_len - ETH_HLEN)) {
 			syslog(LOG_WARNING,"sendto sent only %i instead " \
-			       "of %i bytes on %s: %s\n",
-			       retval,buffer_len,i_s->dev_name,
-			       strerror(errno));
+			       "of %i bytes on %s\n",
+			       retval,buffer_len,i_s->dev_name);
 		}
 	}
 }
 
-void action_handler(int s)
+void action_handler(int UNUSED(s))
 {
 	update_interface_trigger=1;
 	syslog(LOG_DEBUG,"signal caught");
