@@ -6,6 +6,8 @@
  *
  */
 
+#include <stdint.h>
+
 #include "lib/vtoc.h"
 
 static unsigned char EBCtoASC[256] =
@@ -198,7 +200,7 @@ char * vtoc_ebcdic_dec (char *source, char *target, int l)
 /*
  *
  */
-void vtoc_set_extent (extent_t *ext, u_int8_t typeind, u_int8_t seqno,
+void vtoc_set_extent (extent_t *ext, uint8_t typeind, uint8_t seqno,
 		      cchh_t *lower, cchh_t *upper) 
 { 
         ext->typeind = typeind;
@@ -211,17 +213,17 @@ void vtoc_set_extent (extent_t *ext, u_int8_t typeind, u_int8_t seqno,
 /*
  *
  */
-void vtoc_set_cchh (cchh_t *addr, u_int32_t cc, u_int16_t hh)
+void vtoc_set_cchh (cchh_t *addr, uint32_t cc, uint16_t hh)
 {
-	addr->cc = (u_int16_t) cc;
+	addr->cc = (uint16_t) cc;
 	addr->hh = cc >> 16;
 	addr->hh <<= 4;
 	addr->hh |= hh;
 }
 
-u_int32_t vtoc_get_cyl_from_cchh(cchh_t *addr)
+uint32_t vtoc_get_cyl_from_cchh(cchh_t *addr)
 {
-        u_int32_t cyl;
+        uint32_t cyl;
 
         /*decode cylinder for large volumes */
 	cyl = addr->hh & 0xFFF0;
@@ -230,7 +232,7 @@ u_int32_t vtoc_get_cyl_from_cchh(cchh_t *addr)
 	return cyl;
 }
 
-u_int16_t vtoc_get_head_from_cchh(cchh_t *addr)
+uint16_t vtoc_get_head_from_cchh(cchh_t *addr)
 {
 	/* decode heads for large volumes */
 	return addr->hh & 0x000F;
@@ -239,7 +241,7 @@ u_int16_t vtoc_get_head_from_cchh(cchh_t *addr)
 /*
  *
  */
-static void vtoc_set_ttr (ttr_t *addr, u_int16_t tt, u_int8_t r)
+static void vtoc_set_ttr (ttr_t *addr, uint16_t tt, uint8_t r)
 {
 	addr->tt = tt;
 	addr->r  = r;
@@ -249,18 +251,18 @@ static void vtoc_set_ttr (ttr_t *addr, u_int16_t tt, u_int8_t r)
 /*
  *
  */
-void vtoc_set_cchhb (cchhb_t *addr, u_int32_t cc, u_int16_t hh, u_int8_t b)
+void vtoc_set_cchhb (cchhb_t *addr, uint32_t cc, uint16_t hh, uint8_t b)
 {
-	addr->cc = (u_int16_t) cc;
+	addr->cc = (uint16_t) cc;
 	addr->hh = cc >> 16;
 	addr->hh <<= 4;
 	addr->hh |= hh;
 	addr->b  = b;
 }
 
-u_int32_t vtoc_get_cyl_from_cchhb(cchhb_t *addr)
+uint32_t vtoc_get_cyl_from_cchhb(cchhb_t *addr)
 {
-        u_int32_t cyl;
+        uint32_t cyl;
 
         /* decode cylinder for large volumes */
         cyl = addr->hh & 0xFFF0;
@@ -269,7 +271,7 @@ u_int32_t vtoc_get_cyl_from_cchhb(cchhb_t *addr)
 	return cyl;
 }
 
-u_int16_t vtoc_get_head_from_cchhb(cchhb_t *addr)
+uint16_t vtoc_get_head_from_cchhb(cchhb_t *addr)
 {
 	/* decode heads for large volumes */
 	return addr->hh & 0x000F;
@@ -281,22 +283,22 @@ u_int16_t vtoc_get_head_from_cchhb(cchhb_t *addr)
  * Note: Record zero is special, so first block on a track is
  * in record 1!
  */
-u_int64_t cchhb2blk(cchhb_t *p, struct hd_geometry *geo)
+uint64_t cchhb2blk(cchhb_t *p, struct hd_geometry *geo)
 {
-        return (u_int64_t) vtoc_get_cyl_from_cchhb(p) *
+        return (uint64_t) vtoc_get_cyl_from_cchhb(p) *
 		geo->heads * geo->sectors +
 		vtoc_get_head_from_cchhb(p) * geo->sectors +
 		p->b;
 }
 
-u_int64_t cchh2blk (cchh_t *p, struct hd_geometry *geo) {
+uint64_t cchh2blk (cchh_t *p, struct hd_geometry *geo) {
 
-        return (u_int64_t) vtoc_get_cyl_from_cchh(p) *
+        return (uint64_t) vtoc_get_cyl_from_cchh(p) *
 		geo->heads * geo->sectors +
                 vtoc_get_head_from_cchh(p) * geo->sectors;
 }
 
-u_int32_t cchh2trk (cchh_t *p, struct hd_geometry *geo) {
+uint32_t cchh2trk (cchh_t *p, struct hd_geometry *geo) {
 
 	return  vtoc_get_cyl_from_cchh(p) * geo->heads +
 		vtoc_get_head_from_cchh(p);
@@ -305,7 +307,7 @@ u_int32_t cchh2trk (cchh_t *p, struct hd_geometry *geo) {
 /*
  *
  */
-void vtoc_set_date (labeldate_t * d, u_int8_t year, u_int16_t day) 
+void vtoc_set_date (labeldate_t * d, uint8_t year, uint16_t day) 
 {
         d->year = year;
         d->day  = day;
@@ -625,7 +627,7 @@ vtoc_init_format4_label (
 	unsigned int tracks,
 	unsigned int blocks,
 	unsigned int blksize,
-	u_int16_t dev_type) 
+	uint16_t dev_type) 
 {
 	int i;
 
@@ -674,24 +676,24 @@ vtoc_init_format4_label (
         f4->DS4DEVCT.DS4DEVDB = 0x00;
         /* -- end f4->DS4DEVCT -- */
 
-	bzero(f4->DS4AMTIM, sizeof(f4->DS4AMTIM));
-	bzero(f4->DS4AMCAT, sizeof(f4->DS4AMCAT));
-	bzero(f4->DS4R2TIM, sizeof(f4->DS4R2TIM));
-	bzero(f4->res1, sizeof(f4->res1));
-	bzero(f4->DS4F6PTR, sizeof(f4->DS4F6PTR));
+	memset(f4->DS4AMTIM, 0, sizeof(f4->DS4AMTIM));
+	memset(f4->DS4AMCAT, 0, sizeof(f4->DS4AMCAT));
+	memset(f4->DS4R2TIM, 0, sizeof(f4->DS4R2TIM));
+	memset(f4->res1, 0, sizeof(f4->res1));
+	memset(f4->DS4F6PTR, 0, sizeof(f4->DS4F6PTR));
 
         /* -- begin f4lbl->DS4VTOCE -- */
 	vtoc_set_extent(&f4->DS4VTOCE, 0x01, 0x00, &lower, &upper);
         /* -- end f4lbl->DS4VTOCE -- */
 
-	bzero(f4->res2, sizeof(f4->res2));
+	memset(f4->res2, 0, sizeof(f4->res2));
 	f4->DS4EFLVL = 0x00;
-	bzero(&f4->DS4EFPTR, sizeof(f4->DS4EFPTR));
-	bzero(&f4->res3, sizeof(f4->res3));
+	memset(&f4->DS4EFPTR, 0, sizeof(f4->DS4EFPTR));
+	memset(&f4->res3, 0, sizeof(f4->res3));
 	f4->DS4DCYL = real_cylinders;
-	bzero(f4->res4, sizeof(f4->res4));
+	memset(f4->res4, 0, sizeof(f4->res4));
 	f4->DS4DEVF2 = 0x40; /* allow format 8 and 9 labels */
-	bzero(&f4->res5, sizeof(f4->res5));
+	memset(&f4->res5, 0, sizeof(f4->res5));
 }
 
 
@@ -703,7 +705,7 @@ vtoc_init_format5_label (format5_label_t *f5)
 {
 	int i;
 
-	bzero(f5, sizeof(format5_label_t));
+	memset(f5, 0, sizeof(format5_label_t));
 	for (i=0; i<4; i++) f5->DS5KEYID[i] = 0x05;
 	f5->DS5FMTID = 0xf5;
 }
@@ -717,7 +719,7 @@ vtoc_init_format7_label (format7_label_t *f7)
 {
 	int i;
 
-	bzero(f7, sizeof(format7_label_t));
+	memset(f7, 0, sizeof(format7_label_t));
 	for (i=0; i<4; i++) f7->DS7KEYID[i] = 0x07;
 	f7->DS7FMTID = 0xf7;
 }
@@ -740,7 +742,7 @@ static void vtoc_init_format_1_8_label (
 	t = time(NULL);
 	creatime = gmtime(&t);
 
-	bzero(f1->DS1DSNAM, sizeof(f1->DS1DSNAM));
+	memset(f1->DS1DSNAM, 0, sizeof(f1->DS1DSNAM));
 	sprintf(str, "PART    .NEW                                ");
 	vtoc_ebcdic_enc(str, str, 44);
 	memcpy(f1->DS1DSNAM, str, 44);
@@ -748,8 +750,8 @@ static void vtoc_init_format_1_8_label (
 	f1->DS1VOLSQ = 0x0001;
 
 	vtoc_set_date(&f1->DS1CREDT,
-		      (u_int8_t) creatime->tm_year,
-		      (u_int16_t) creatime->tm_yday);
+		      (uint8_t) creatime->tm_year,
+		      (uint16_t) creatime->tm_yday);
 	/* expires never - 99 365 */
 	vtoc_set_date(&f1->DS1EXPDT,
 	              0x63,
@@ -760,8 +762,8 @@ static void vtoc_init_format_1_8_label (
 	vtoc_ebcdic_enc("IBM LINUX    ", str, 13);
 	memcpy((char *)f1->DS1SYSCD, str, 13);
 	vtoc_set_date(&f1->DS1REFD,
-		      (u_int8_t) creatime->tm_year,
-		      (u_int16_t) creatime->tm_yday);
+		      (uint8_t) creatime->tm_year,
+		      (uint16_t) creatime->tm_yday);
 	f1->DS1SMSFG = 0x00;
 	f1->DS1SCXTF = 0x00;
 	f1->DS1SCXTV = 0x0000;
@@ -775,17 +777,17 @@ static void vtoc_init_format_1_8_label (
 	f1->DS1RKP   = 0x0000;
 	f1->DS1DSIND = 0x80; /* last volume for this dataset */
 	f1->DS1SCAL1 = 0x80;
-	bzero(&f1->DS1SCAL3, sizeof(f1->DS1SCAL3));
+	memset(&f1->DS1SCAL3, 0, sizeof(f1->DS1SCAL3));
 	vtoc_set_ttr(&f1->DS1LSTAR,
 		     0x0000,
 		     0x00);
 	f1->DS1TRBAL = 0x00;
-	bzero(&f1->res1, sizeof(f1->res1));
+	memset(&f1->res1, 0, sizeof(f1->res1));
 	memcpy(&f1->DS1EXT1,
 	       part_extent,
 	       sizeof(extent_t));
-	bzero(&f1->DS1EXT2, sizeof(extent_t));
-	bzero(&f1->DS1EXT3, sizeof(extent_t));
+	memset(&f1->DS1EXT2, 0, sizeof(extent_t));
+	memset(&f1->DS1EXT3, 0, sizeof(extent_t));
 	vtoc_set_cchhb(&f1->DS1PTRDS,
 		       0x0000, 0x0000, 0x00);
 }
@@ -831,7 +833,7 @@ void
 vtoc_update_format4_label (
 	format4_label_t *f4,
 	cchhb_t *highest_f1,
-	u_int16_t unused_update) 
+	uint16_t unused_update) 
 {
 	/* update highest address of a format 1 label */
 	memcpy(&f4->DS4HPCHR, highest_f1, sizeof(cchhb_t));
@@ -893,9 +895,9 @@ void
 vtoc_update_format5_label_add (format5_label_t *f5,
 			       int verbose,
 			       int trk,
-			       u_int16_t a, 
-			       u_int16_t b, 
-			       u_int8_t c) 
+			       uint16_t a, 
+			       uint16_t b, 
+			       uint8_t c) 
 {
 	ds5ext_t *ext = NULL, *tmp = NULL;
 	int i;	
@@ -954,7 +956,7 @@ vtoc_update_format5_label_add (format5_label_t *f5,
 			/* this extent precedes the new one */
 			ext->fc += (tmp->fc + (tmp->ft + ext->ft)/trk);
 			ext->ft = (tmp->ft + ext->ft) % trk;
-			bzero(tmp, sizeof(ds5ext_t));
+			memset(tmp, 0, sizeof(ds5ext_t));
 			tmp = ext;
 			if (verbose) 
 				printf("FMT5 add extent: " \
@@ -969,7 +971,7 @@ vtoc_update_format5_label_add (format5_label_t *f5,
 			ext->t = tmp->t;
 			ext->fc += (tmp->fc + (tmp->ft + ext->ft)/trk);
 			ext->ft = (tmp->ft + ext->ft) % trk;
-			bzero(tmp, sizeof(ds5ext_t));
+			memset(tmp, 0, sizeof(ds5ext_t));
 			tmp = ext;
 			if (verbose) 
 				printf("FMT5 add extent: " \
@@ -988,9 +990,9 @@ void
 vtoc_update_format5_label_del (format5_label_t *f5,
 			       int verbose,
 			       int trk,
-			       u_int16_t a,
-			       u_int16_t b,
-			       u_int8_t c) 
+			       uint16_t a,
+			       uint16_t b,
+			       uint8_t c) 
 {
 	ds5ext_t *ext;
 	int i, counter=0;
@@ -1007,7 +1009,7 @@ vtoc_update_format5_label_del (format5_label_t *f5,
 		if ((a == ext->t) && (b == ext->fc) && (c == ext->ft))
 		{
 			/* fills up whole free space gap */
-			bzero(ext, sizeof(ds5ext_t));
+			memset(ext, 0, sizeof(ds5ext_t));
 			if (verbose) 
 				printf("FMT5 del extent: fills whole gap\n");
 			counter++;
@@ -1057,10 +1059,10 @@ vtoc_update_format5_label_del (format5_label_t *f5,
 		if ((a > ext->t) &&
 			((ext->t + ext->fc*trk + ext->ft) > (a + b*trk + c)))
 		{
-			/* partition devides free space into 2 pieces */
-			u_int16_t x = a + b*trk + c;
-			u_int16_t w,y;
-			u_int8_t z;
+			/* partition divides free space into 2 pieces */
+			uint16_t x = a + b*trk + c;
+			uint16_t w,y;
+			uint8_t z;
 
 			w = (ext->t + ext->fc*trk + ext->ft) - (a + b*trk + c);
 			y = w / trk;
@@ -1149,7 +1151,7 @@ vtoc_reorganize_FMT7_extents (format7_label_t *f7)
  * add a free space extent description to the VTOC FMT7 DSCB
  */
 void vtoc_update_format7_label_add (format7_label_t *f7, int verbose, 
-				    u_int32_t a, u_int32_t b) 
+				    uint32_t a, uint32_t b) 
 {
 	ds7ext_t *ext = NULL, *tmp = NULL;
 	int i;	
@@ -1194,7 +1196,7 @@ void vtoc_update_format7_label_add (format7_label_t *f7, int verbose,
 		if ((ext->b) == tmp->a) {
 			/* this extent precedes the new one */
 			ext->b = tmp->b;
-			bzero(tmp, sizeof(ds7ext_t));
+			memset(tmp, 0, sizeof(ds7ext_t));
 			tmp = ext;
 			if (verbose) 
 				printf("FMT7 add extent: " \
@@ -1207,7 +1209,7 @@ void vtoc_update_format7_label_add (format7_label_t *f7, int verbose,
 		{
 			/* this extent succeeds the new one */
 			ext->a = tmp->a;
-			bzero(tmp, sizeof(ds7ext_t));
+			memset(tmp, 0, sizeof(ds7ext_t));
 			tmp = ext;
 			if (verbose) 
 				printf("FMT7 add extent: " \
@@ -1223,7 +1225,7 @@ void vtoc_update_format7_label_add (format7_label_t *f7, int verbose,
  * remove a free space extent description from the VTOC FMT7 DSCB
  */
 void vtoc_update_format7_label_del (format7_label_t *f7, int verbose, 
-				    u_int32_t a, u_int32_t b) 
+				    uint32_t a, uint32_t b) 
 {
 	ds7ext_t *ext;
 	int i, counter=0;
@@ -1236,7 +1238,7 @@ void vtoc_update_format7_label_del (format7_label_t *f7, int verbose,
 
 		if ((a == ext->a) && (b == ext->b)) {
 			/* fills up whole free space gap */
-			bzero(ext, sizeof(ds7ext_t));
+			memset(ext, 0, sizeof(ds7ext_t));
 			if (verbose) 
 				printf("FMT7 del extent: fills whole gap\n");
 			counter++;
@@ -1262,7 +1264,7 @@ void vtoc_update_format7_label_del (format7_label_t *f7, int verbose,
 		}
 
 		if ((a > ext->a) && (b < ext->b)) {
-			/* partition devides free space into 2 pieces */
+			/* partition divides free space into 2 pieces */
 			vtoc_update_format7_label_add(f7, verbose, 
 						      b, ext->b);
 			ext->b = a;
@@ -1294,7 +1296,7 @@ void vtoc_update_format7_label_del (format7_label_t *f7, int verbose,
  */
 void vtoc_set_freespace(format4_label_t *f4, format5_label_t *f5,
 		   format7_label_t *f7, char ch, int verbose,
-		   u_int32_t start, u_int32_t stop, u_int32_t cyl, u_int32_t trk)
+		   uint32_t start, uint32_t stop, uint32_t cyl, uint32_t trk)
 {
 	if ((cyl * trk) > BIG_DISK_SIZE) {
 		if (ch == '+') {
@@ -1317,12 +1319,12 @@ void vtoc_set_freespace(format4_label_t *f4, format5_label_t *f5,
 		f4->DS4EFLVL = 0x07;
 		vtoc_set_cchhb(&f4->DS4EFPTR, 0x0000, 0x0001, 0x03);
 	} else {
-		u_int16_t x,y;
-		u_int8_t  z;
+		uint16_t x,y;
+		uint8_t  z;
 
-		x = (u_int16_t) start;
-		y = (u_int16_t) ((stop - start + 1) / trk);
-		z =  (u_int8_t) ((stop - start + 1) % trk);
+		x = (uint16_t) start;
+		y = (uint16_t) ((stop - start + 1) / trk);
+		z =  (uint8_t) ((stop - start + 1) % trk);
 
 		if (ch == '+') {
 			vtoc_update_format5_label_add(f5, verbose, trk,
