@@ -143,7 +143,7 @@ impl ApConfigEntry {
                 self.mode = mode;
                 self.validate_accel_entry()?;
             }
-            _ => return Err(format!("Unknown or invalid mode '{}'.", mode)),
+            _ => return Err(format!("Unknown or invalid mode '{mode}'.")),
         }
         Ok(())
     }
@@ -174,19 +174,11 @@ impl ApConfigList {
     fn read_yaml_file(fname: &str) -> Result<Vec<ApConfigEntry>, String> {
         let file = match File::open(fname) {
             Ok(f) => f,
-            Err(err) => {
-                return Err(format!(
-                    "Failure to open AP config file {}: {:?}",
-                    fname, err
-                ))
-            }
+            Err(err) => return Err(format!("Failure to open AP config file {fname}: {err:?}")),
         };
         match serde_yaml::from_reader(file) {
             Ok(cfg) => Ok(cfg),
-            Err(err) => Err(format!(
-                "Failure parsing AP config file {}: {:?}",
-                fname, err
-            )),
+            Err(err) => Err(format!("Failure parsing AP config file {fname}: {err:?}")),
         }
     }
 
@@ -195,10 +187,10 @@ impl ApConfigList {
             let ename = if !entry.name.trim().is_empty() {
                 format!("AP config entry {} '{}'", i, entry.name.trim())
             } else {
-                format!("AP config entry {}", i)
+                format!("AP config entry {i}")
             };
             if let Err(err) = &entry.validate() {
-                return Err(format!("{}: {}", ename, err));
+                return Err(format!("{ename}: {err}"));
             }
         }
         Ok(())
