@@ -9,24 +9,14 @@ use log::{self, Level, LevelFilter, Log, Metadata, Record};
 #[derive(Clone, Default, Debug)]
 pub struct PvLogger;
 
-fn to_level(verbosity: u8) -> LevelFilter {
-    match verbosity {
-        // Error and Warn on by default
-        0 => LevelFilter::Warn,
-        1 => LevelFilter::Info,
-        2 => LevelFilter::Debug,
-        _ => LevelFilter::Trace,
-    }
-}
-
 impl PvLogger {
     /// Set self as the logger for this application.
     ///
     /// # Errors
     ///
     /// An error is returned if a logger has already been set.
-    pub fn start(&'static self, verbosity: u8) -> Result<(), log::SetLoggerError> {
-        log::set_logger(self).map(|()| log::set_max_level(to_level(verbosity)))
+    pub fn start(&'static self, filter: LevelFilter) -> Result<(), log::SetLoggerError> {
+        log::set_logger(self).map(|()| log::set_max_level(filter))
     }
 }
 
