@@ -316,8 +316,7 @@ PROCFILES="\
   /proc/cmdline\
   /proc/cpuinfo\
   /proc/crypto\
-  /proc/dasd/devices\
-  /proc/dasd/statistics\
+  /proc/dasd\
   /proc/devices\
   /proc/diskstats\
   /proc/interrupts\
@@ -328,11 +327,7 @@ PROCFILES="\
   /proc/misc\
   /proc/modules\
   /proc/mounts\
-  /proc/net/vlan\
-  /proc/net/bonding\
-  /proc/net/sockstat\
-  /proc/net/sockstat6\
-  /proc/net/softnet_stat\
+  /proc/net\
   /proc/partitions\
   /proc/qeth\
   /proc/qeth_perf\
@@ -435,8 +430,10 @@ CONFIGFILES="\
   /etc/modules-load.d/*.conf\
   /etc/mtab\
   /etc/multipath\
+  /etc/netplan\
   /etc/network\
   /etc/networks\
+  /etc/NetworkManager\
   /etc/opencryptoki/*.conf\
   /etc/pam.d\
   /etc/profile\
@@ -490,6 +487,7 @@ CMDS="uname -a\
   :lsmem\
   :lsmod\
   :lsshut\
+  :lsstp\
   :runlevel\
   :sysctl -a\
   :systemctl --all --no-pager show\
@@ -747,6 +745,7 @@ KVM_CMDS="virsh version\
   :virsh nodedev-list --tree\
   :virsh pool-list\
   :virt-host-validate\
+  :kvm_stat --once --debugfs --debugfs-include-past --tracepoints\
   "
 
 ########################################
@@ -1299,11 +1298,28 @@ collect_kvm() {
 
 		# domain/guest specific commands
 		domain_list=$(virsh list --all --name)
+		path="/machine/sclp/s390-sclp-event-facility/sclpcpi"
+		props="timestamp\
+			system_name\
+			system_type\
+			system_level\
+			sysplex_name"
 		if test -n "${domain_list}"; then
 			for domain in ${domain_list}; do
 				call_run_command "virsh dominfo ${domain}" "${OUTPUT_FILE_KVM}"
 				call_run_command "virsh domblklist ${domain}" "${OUTPUT_FILE_KVM}"
 				call_run_command "virsh domstats ${domain}" "${OUTPUT_FILE_KVM}"
+				for prop in ${props}; do
+					qm=$(printf '{
+						"execute": "qom-get",
+						"arguments": {
+							"path": "%s",
+							"property": "%s"
+							}
+						}' "${path}" "${prop}")
+					call_run_command "virsh qemu-monitor-command ${domain} \
+						--pretty '${qm}'" "${OUTPUT_FILE_KVM}"
+				done
 			done
 		else
 			echo "no KVM domains found" | tee -a ${OUTPUT_FILE_KVM}
