@@ -7,11 +7,11 @@
  * it under the terms of the MIT license. See LICENSE for details.
  */
 
+#include <libgen.h>
 #include <stdio.h>
 #include <stdlib.h>
 
 #include "lib/ccw.h"
-#include "lib/util_base.h"
 #include "lib/util_file.h"
 #include "lib/util_libc.h"
 #include "lib/util_list.h"
@@ -21,7 +21,6 @@
 #include "lib/util_rec.h"
 #include "lib/util_scandir.h"
 #include "lib/util_panic.h"
-#include "lib/zt_common.h"
 
 #include "misc.h"
 
@@ -72,7 +71,7 @@ enum sch_type {
  * Private data
  */
 static struct lscss_cmd_opts {
-	/* Boolean flags to indicate wich command options are in effect */
+	/* Boolean flags to indicate which command options are in effect */
 	bool opt_short;		/* -s or --short */
 	bool opt_devtype;	/* -t or --devtype */
 	bool opt_devrange;	/* -d or --devrange */
@@ -245,7 +244,7 @@ static bool id_in_ranges_list(const char *id)
  * @param[in,out] dt   Pointer to devtype structure to be initialized
  * @parm[in]      id   String to parse
  *
- * @returns       true if the input string has been parsed successfuly;
+ * @returns       true if the input string has been parsed successfully;
  *                otherwise false
  */
 static bool parse_devtype_str(struct devtype *dt, const char *id)
