@@ -9,11 +9,9 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
 #include <err.h>
 #include <errno.h>
 #include <stdbool.h>
-#include <stdlib.h>
 #include <stdio.h>
 
 #include "lib/util_libc.h"
@@ -25,7 +23,6 @@
 #include "ccw.h"
 #include "device.h"
 #include "devtype.h"
-#include "internal.h"
 #include "misc.h"
 #include "namespace.h"
 #include "path.h"
@@ -289,6 +286,8 @@ static exit_code_t ap_write_type_udev(char *ap, char *aq, bool autoconf)
 	fprintf(fd, "# Generated by chzdev\n");
 
 	/* Triggers. */
+	fprintf(fd, "ACTION==\"add\", DEVPATH==\"/bus/ap\", "
+		"ATTR{bindings_complete_count}!=\"0\", GOTO=\"cfg_ap\"\n");
 	fprintf(fd, "ACTION==\"change\", SUBSYSTEM==\"ap\", "
 		"DEVPATH==\"/devices/ap\", ENV{BINDINGS}==\"complete\", "
 		"ENV{COMPLETECOUNT}==\"1\", GOTO=\"cfg_ap\"\n");
