@@ -8,12 +8,12 @@
  */
 
 #include <inttypes.h>
+#include <libgen.h>
 #include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "lib/util_base.h"
 #include "lib/util_path.h"
 
 #include "attrib.h"
