@@ -16,7 +16,7 @@
 
 
 #define SCAN_SECTION_NUM		9
-#define SCAN_KEYWORD_NUM		22
+#define SCAN_KEYWORD_NUM		23
 #define SCAN_KEYWORD_ONLY_NUM		1
 #define SCAN_AUTOMENU_NAME		"zipl-automatic-menu"
 
@@ -52,6 +52,7 @@ enum scan_keyword_id {
 	scan_keyword_defaultauto = 19,
 	scan_keyword_kdump = 20,
 	scan_keyword_secure = 21,
+	scan_keyword_optional = 22,
 };
 
 enum scan_section_type {
@@ -115,18 +116,20 @@ struct scan_token {
 	} content;
 };
 
+extern const char *blsdir;
+
 /* Determines which keyword may be present in which section */
 extern enum scan_key_state scan_key_table[SCAN_SECTION_NUM][SCAN_KEYWORD_NUM];
 
 
 int scan_file(const char* filename, struct scan_token** array);
-int scan_bls(const char* blsdir, struct scan_token** token, int scan_size);
+int scan_bls(struct scan_token **token, int scan_size);
 void scan_free(struct scan_token* array);
 char* scan_keyword_name(enum scan_keyword_id id);
 int scan_check_defaultboot(struct scan_token* scan);
 struct scan_token* scan_build_automenu(struct scan_token* scan);
 int scan_check(struct scan_token* scan);
-int scan_check_bls(struct scan_token *scan);
+void scan_update_bls_path(struct scan_token *scan);
 int scan_find_section(struct scan_token* scan, char* name, enum scan_id type,
 		      int offset);
 int scan_check_section_data(char* keyword[], int* line, char* name,
